# قیمت لحظه‌ای تقریبا همه چیز! | Gheymat

کتابخانه‌ای برای دریافت قیمت ارزها و طلا و...
اگر به دردت خورد و اگر دوس داشتی برام یه کافی بخر 😁
https://www.coffeebede.com/mrrobat

## آخرین آپدیت
- قیمت دلار اضافه شد - USD
- قیمت پوند اضافه شد - GBP

## نصب
```bash
pip install gheymat
```

## استفاده
```python
from gheymat.currency import USD #or GBP

dollar_price = USD(toman=True)
print(dollar_price)
```